You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by an...@apache.org on 2009/05/28 18:41:44 UTC

svn commit: r779654 - /jackrabbit/trunk/jackrabbit-spi-commons/src/main/java/org/apache/jackrabbit/spi/commons/value/AbstractQValue.java

Author: angela
Date: Thu May 28 16:41:43 2009
New Revision: 779654

URL: http://svn.apache.org/viewvc?rev=779654&view=rev
Log:
JCR-1609  new Property Types

missing special treatment for WEAKREFERENCEs

Modified:
    jackrabbit/trunk/jackrabbit-spi-commons/src/main/java/org/apache/jackrabbit/spi/commons/value/AbstractQValue.java

Modified: jackrabbit/trunk/jackrabbit-spi-commons/src/main/java/org/apache/jackrabbit/spi/commons/value/AbstractQValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/trunk/jackrabbit-spi-commons/src/main/java/org/apache/jackrabbit/spi/commons/value/AbstractQValue.java?rev=779654&r1=779653&r2=779654&view=diff
==============================================================================
--- jackrabbit/trunk/jackrabbit-spi-commons/src/main/java/org/apache/jackrabbit/spi/commons/value/AbstractQValue.java (original)
+++ jackrabbit/trunk/jackrabbit-spi-commons/src/main/java/org/apache/jackrabbit/spi/commons/value/AbstractQValue.java Thu May 28 16:41:43 2009
@@ -66,13 +66,14 @@
      * @param value
      * @param type
      * @throws IllegalArgumentException if the passed <code>value</code>
      * is <code>null</code> or if the <code>type</code> is neither STRING nor REFERENCE.
      */
     protected AbstractQValue(String value, int type) {
         if (value == null) {
             throw new IllegalArgumentException("null value");
         }
-        if (!(type == PropertyType.STRING || type == PropertyType.REFERENCE)) {
+        if (!(type == PropertyType.STRING || type == PropertyType.REFERENCE || type == PropertyType.WEAKREFERENCE)) {
             throw new IllegalArgumentException();
         }
         val = value;
@@ -66,13 +66,14 @@
      * @param type
      * @throws IllegalArgumentException if the passed <code>value</code>
-     * is <code>null</code> or if the <code>type</code> is neither STRING nor REFERENCE.
+     * is <code>null</code> or if the <code>type</code> is neither STRING nor
+     * REFERENCE/WEAKREFERENCE.
      */
     protected AbstractQValue(String value, int type) {